@@ -8,18 +8,20 @@
 #' @export
 #'
 #' @examples
-#'\donttest{
-#'mymemory_translate("Hello World", target_language = "es", source_language = "en")
-#'}
+#' \donttest{
+#' mymemory_translate("Hello World", target_language = "es", source_language = "en")
+#' }
 mymemory_translate <- function(text, target_language = "en", source_language = "auto") {
   formatted_text <- stringr::str_replace_all(text, " ", "%20")
 
-  formatted_link <- paste0("https://api.mymemory.translated.net/get?q=",
-                           formatted_text,
-                           "&langpair=",
-                           source_language,
-                           "|",
-                           target_language)
+  formatted_link <- paste0(
+    "https://api.mymemory.translated.net/get?q=",
+    formatted_text,
+    "&langpair=",
+    source_language,
+    "|",
+    target_language
+  )
 
   response <- httr::GET(formatted_link) %>%
     httr::content()
@@ -27,5 +29,4 @@ mymemory_translate <- function(text, target_language = "en", source_language = "
   translation <- response$responseData$translatedText
 
   return(translation)
-
 }
