@@ -1,10 +1,10 @@
-test_that("translation workds", {
+test_that("translation works", {
   expect_equal(
     mymemory_translate(
       text = "Hello",
-      target_language = "es",
+      target_language = "nl",
       source_language = "en"
     ),
-    "Hola"
+    "Hallo"
   )
 })
